@@ -1,8 +1,14 @@
 # -*- coding: UTF-8 -*-
-
 import random
 
-class Board():
+# PY3 compat
+try:
+    xrange
+except NameError:
+    xrange = range
+
+
+class Board(object):
     """
     A 2048 board
     """
@@ -21,11 +27,13 @@ class Board():
         self.addTile()
 
     def size(self):
-        """
-        return the board size
-        """
+        """return the board size"""
         return self.__size
 
+    def goal(self):
+        """return the board goal"""
+        return self.__goal
+
     def won(self):
         """
         return True if the board contains at least one tile with the board goal
@@ -54,12 +62,12 @@ class Board():
         """
         return len(self.getEmptyCells()) == 0
 
-    def addTile(self, value=None, choices=[2, 4]):
+    def addTile(self, value=None, choices=([2]*9+[4])):
         """
         add a random tile in an empty cell
           value: value of the tile to add.
           choices: a list of possible choices for the value of the tile.
-                   default is [2, 4].
+                   default is [2, 2, 2, 2, 2, 2, 2, 2, 2, 4].
         """
         if value:
             choices = [value]
