@@ -1,34 +1,47 @@
 # -*- coding: UTF-8 -*-
+from __future__ import print_function
 
 import os
 import os.path
-import keypress
-from board import Board
-from colorama import init, Fore
+import math
+
+from colorama import init, Fore, Style
+
+from term2048 import keypress
+from term2048.board import Board
+
+# PY3 compat
+try:
+    xrange
+except NameError:
+    xrange = range
+
+
 init(autoreset=True)
 
-class Game:
+
+class Game(object):
     """
     A 2048 game
     """
 
     __dirs = {
-        keypress.UP:    Board.UP,
-        keypress.DOWN:  Board.DOWN,
-        keypress.LEFT:  Board.LEFT,
-        keypress.RIGHT: Board.RIGHT,
+        keypress.UP:      Board.UP,
+        keypress.DOWN:    Board.DOWN,
+        keypress.LEFT:    Board.LEFT,
+        keypress.RIGHT:   Board.RIGHT,
     }
 
     __clear = 'cls' if os.name == 'nt' else 'clear'
 
     COLORS = {
            2: Fore.GREEN,
-           4: Fore.BLUE,
+           4: Fore.BLUE + Style.BRIGHT,
            8: Fore.CYAN,
           16: Fore.RED,
           32: Fore.MAGENTA,
           64: Fore.CYAN,
-         128: Fore.BLUE,
+         128: Fore.BLUE + Style.BRIGHT,
          256: Fore.MAGENTA,
          512: Fore.GREEN,
         1024: Fore.RED,
@@ -49,7 +62,7 @@ class Game:
     SCORES_FILE = '%s/.term2048.scores' % os.path.expanduser('~')
 
     def __init__(self, scores_file=SCORES_FILE, colors=COLORS,
-            mode=None, **kws):
+            mode=None, azmode=False, **kws):
         """
         Create a new game.
             scores_file: file to use for the best score (default
@@ -65,6 +78,7 @@ class Game:
         self.__colors = colors
         self.loadBestScore()
         self.adjustColors(mode)
+        self.__azmode = azmode
 
     def adjustColors(self, mode='dark'):
         """
@@ -104,6 +118,14 @@ class Game:
         except:
             pass # fail silently
 
+    def incScore(self, pts):
+        """
+        update the current score by adding it the specified number of points
+        """
+        self.score += pts
+        if self.score > self.best_score:
+            self.best_score = self.score
+
     def end(self):
         """
         return True if the game is finished
@@ -114,44 +136,55 @@ class Game:
         """
         read and return a move to pass to a board
         """
-        k = keypress.getArrowKey()
+        k = keypress.getKey()
         return Game.__dirs.get(k)
 
     def loop(self):
         """
         main game loop
         """
-        while True:
-            os.system(Game.__clear)
-            print self.__str__(margins={'left':4, 'top':4, 'bottom':4})
-            if self.board.won() or not self.board.canMove():
-                break
-            try:
-                m = self.readMove()
-            except KeyboardInterrupt:
-                self.saveBestScore()
-                return
-            self.score += self.board.move(m)
-            if self.score > self.best_score:
-                self.best_score = self.score
+        try:
+            while True:
+                os.system(Game.__clear)
+                print(self.__str__(margins={'left':4, 'top':4, 'bottom':4}))
+                if self.board.won() or not self.board.canMove():
+                    break
+                    m = self.readMove()
+                self.incScore(self.board.move(m))
+
+        except KeyboardInterrupt:
+            self.saveBestScore()
+            return
 
         self.saveBestScore()
-        print 'You won!' if self.board.won() else 'Game Over'
+        print('You won!' if self.board.won() else 'Game Over')
 
     def getCellStr(self, x, y):
         """
         return a string representation of the cell located at x,y.
         """
         c = self.board.getCell(x, y)
-        if c == 0:
+
+        az = {}
+        for i in range(1, int(math.log(self.board.goal(), 2))):
+            az[2**i] = chr(i+96)
+
+        if c==0 and self.__azmode:
+            return '.'
+        elif c == 0:
             return '  .'
 
-        if c == 1024:
+        elif self.__azmode:
+            if c not in az:
+                return '?'
+            s = az[c]
+        elif c == 1024:
             s = ' 1k'
         elif c == 2048:
             s = ' 2k'
         else:
             s = '%3d' % c
+
         return self.__colors.get(c, Fore.RESET) + s + Fore.RESET
 
     def boardToString(self, margins={}):
